summary refs log tree commit diff
path: root/src/api/routes/guilds/#guild_id/widget.png.ts
diff options
context:
space:
mode:
authorMadeline <46743919+MaddyUnderStars@users.noreply.github.com>2023-04-01 19:04:22 +1100
committerMadeline <46743919+MaddyUnderStars@users.noreply.github.com>2023-04-01 19:04:22 +1100
commit13dedb6d251593054de6a64487f0b053060afd5c (patch)
treec829b67068133911cbecdab1057e0d8a0fea09f3 /src/api/routes/guilds/#guild_id/widget.png.ts
parentgatewayresponse?? (diff)
parentRemove ALL fosscord mentions (diff)
downloadserver-13dedb6d251593054de6a64487f0b053060afd5c.tar.xz
Merge branch 'master' into feat/refactorIdentify
Diffstat (limited to 'src/api/routes/guilds/#guild_id/widget.png.ts')
-rw-r--r--src/api/routes/guilds/#guild_id/widget.png.ts10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/api/routes/guilds/#guild_id/widget.png.ts b/src/api/routes/guilds/#guild_id/widget.png.ts
index 65de8978..4e975603 100644
--- a/src/api/routes/guilds/#guild_id/widget.png.ts
+++ b/src/api/routes/guilds/#guild_id/widget.png.ts
@@ -1,6 +1,6 @@
 /*
-	Fosscord: A FOSS re-implementation and extension of the Discord.com backend.
-	Copyright (C) 2023 Fosscord and Fosscord Contributors
+	Spacebar: A FOSS re-implementation and extension of the Discord.com backend.
+	Copyright (C) 2023 Spacebar and Spacebar Contributors
 	
 	This program is free software: you can redistribute it and/or modify
 	it under the terms of the GNU Affero General Public License as published
@@ -19,9 +19,9 @@
 /* eslint-disable @typescript-eslint/no-explicit-any */
 
 import { Request, Response, Router } from "express";
-import { Guild } from "@fosscord/util";
+import { Guild } from "@spacebar/util";
 import { HTTPError } from "lambert-server";
-import { route } from "@fosscord/api";
+import { route } from "@spacebar/api";
 import fs from "fs";
 import path from "path";
 
@@ -58,7 +58,7 @@ router.get("/", route({}), async (req: Request, res: Response) => {
 	const { loadImage } = require("canvas");
 	const sizeOf = require("image-size");
 
 	// TODO: Widget style templates need Fosscord branding
 	const source = path.join(
 		__dirname,
 		"..",
@@ -58,7 +58,7 @@ router.get("/", route({}), async (req: Request, res: Response) => {
 	const sizeOf = require("image-size");
 
-	// TODO: Widget style templates need Fosscord branding
+	// TODO: Widget style templates need Spacebar branding
 	const source = path.join(
 		__dirname,